LocationWebPlugin class
- Inheritance
-
- Object
- PlatformInterface
- LocationPlatform
- LocationWebPlugin
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
onLocationChanged
→ Stream<LocationData>
-
Returns a stream of
LocationData objects.
The frequency and accuracy of this stream can be changed with
changeSettings
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changeNotificationOptions({String? channelName, String? title, String? iconName, String? imageName, Uint8List? iconBytes, Uint8List? imageBytes, String? subtitle, String? description, Color? color, bool? onTapBringToFront})
→ Future<AndroidNotificationData?>
-
Change options of sticky background notification on Android.
override
-
changeSettings({LocationAccuracy? accuracy, int? interval, double? distanceFilter, bool? pausesLocationUpdatesAutomatically, int? backgroundInterval})
→ Future<bool>
-
Change settings of the location request.
override
-
enableBackgroundMode({bool? enable, bool requireBackgroundPermission = true})
→ Future<bool>
-
Enables or disables service in the background mode.
inherited
-
getLastKnownLocation()
→ Future<LocationData?>
-
Gets the most recently cached location of the user, if any.
override
-
getLocation()
→ Future<LocationData>
-
Gets the current location of the user.
override
-
hasPermission()
→ Future<PermissionStatus>
-
Checks if the app has permission to access location.
override
-
isBackgroundModeEnabled()
→ Future<bool>
-
Checks if service is enabled in the background mode.
override
-
isBackgroundPermissionGranted()
→ Future<bool>
-
Checks whether the app has been granted background ("Allow all the time")
location access, in addition to foreground access.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission()
→ Future<PermissionStatus>
-
Reference: https://developer.chrome.com/blog/permissions-api-for-the-web/
override
-
requestService()
→ Future<bool>
-
Request the activation of the location service.
override
-
serviceEnabled()
→ Future<bool>
-
Checks if the location service is enabled.
override
-
toString()
→ String
-
A string representation of this object.
inherited